import ReactFlagsSelect from 'react-flags-select';
import {createRef, useEffect, useMemo, useRef, useState} from 'react';
import {useGetTranslatePost, useLanguage, useTranslatePost} from '../../services/WordpressService';
import {convertCountries, getLanguageCodeFromCountryCode} from '../../resources/countries';
import classNames from 'classnames';
import {AiFillDelete} from 'react-icons/ai';
import toast from 'react-hot-toast';

const TranslateSelector = () => {
    const [post, setPost] = useState(null);
    const [selected, setSelected] = useState('US');
    const [customSelectLanguage, setCustomSelectLanguage] = useState([]);
    const [isOpen, setIsOpen] = useState(false);
    const [listTranslated, setListTranslated] = useState([]);
    const [listTranslate, setListTranslate] = useState([]);
    const translatedRef = useRef(null);

    const {data: wordpressSettings} = useLanguage();
    const {
        mutateAsync: getTranslatePostAsync,
        data: dataTranslate,
        isLoading: isGetTranslateLoading
    } = useGetTranslatePost();
    const {mutateAsync: translatePostAsync, isLoading: isTranslatePostLoading} = useTranslatePost();

    useEffect(() => {
        const urlParams = new URLSearchParams(window.location.search);
        const postId = urlParams.get('post');
        if (postId) {
            setPost(postId);
        }
    }, []);

    useEffect(() => {
        if (wordpressSettings?.data?.turbotranslateGetCountryCodeSelected) {
            let arr = [];
            Object.keys(wordpressSettings?.data?.turbotranslateGetCountryCodeSelected)?.map((key) => {
                if (key === 'zhCn')
                    key = 'zh-cn';
                arr.push(key);
            });

            const dataLanguage = arr.length && arr?.map(item => convertCountries.find(country => country.shortName === item)).filter(item => item !== undefined);

            if (dataLanguage?.length) {
                setCustomSelectLanguage([...dataLanguage?.map(l => l.code)]);
            }
        }
    }, [wordpressSettings]);

    const onGetTranslatePost = (e) => {
        e.preventDefault();
        getTranslatePostAsync({
            postId: post,
            shop: window.location.hostname,
            targetLang: getLanguageCodeFromCountryCode(selected),
        }).then(res => {
            // console.log('DEBUGG :::');
            // console.log(res.data.translatedQuery);
            // console.log('DEBUGG :::');

            if (res?.data?.status) {
                const listRemoveIndex = [];

                res?.data?.translatedQuery.forEach(v => {
                    if( v !== null ){ /// exclude null items
                        v = v.trim();
                        let error = false;
                        if (
                            /^(\d+(?:[.,]\d{2})?|\d+(?:[.,]\d)?|[.,]\d{2}|\d)$/.test(v) ||
                            /^[#$]+$/.test(v) ||
                            ((v.includes(',') || v.includes('.') || v.includes(';')
                                    || v.includes(':') || v.includes('!') || v.includes('?')
                                    || v.includes(')') || v.includes('(') || v.includes('[')
                                    || v.includes(']') || v.includes('{') || v.includes('}')
                                    || v.includes('\'') || v.includes('"') || v.includes('`')
                                    || v.includes('~') || v.includes('@') || v.includes('#')
                                    || v.includes('$') || v.includes('%') || v.includes('^')
                                    || v.includes('&') || v.includes('*') || v.includes('-')
                                    || v.includes('_') || v.includes('+') || v.includes('=')
                                    || v.includes('|') || v.includes('\\') || v.includes('/')
                                    || v.includes('<') || v.includes('>') || v.includes('…')
                                    || v.includes('–') || v.includes('—') || v.includes('•')
                                    || v.includes('·') || v.includes('«') || v.includes('»')) &&
                                v.split(' ').length <= 2)
                        )
                            error = true;

                        if (error) {
                            listRemoveIndex.push(v);
                        }
                    }    
                })

                if (listRemoveIndex.length) {
                    listRemoveIndex.forEach(value => {
                        let index = res?.data?.translatedQuery.indexOf(value);
                        res?.data?.translatedQuery.splice(index, 1);
                        res?.data?.translateQuery.splice(index, 1);
                    })
                }

                setListTranslated(res?.data?.translatedQuery);
                setListTranslate(res?.data?.translateQuery);
                translatedRef.current = Array.from({length: res?.data?.translatedQuery.length}, (v, i) => createRef());
                setIsOpen(true);
            }
        });
    };

    const handleChange = (index, e) => {
        const {value} = e.target;
        const newTranslated = [...listTranslated];
        newTranslated[index] = value;
        setListTranslated(newTranslated);
    };

    console.log(listTranslated)
    console.log(listTranslate)

    const renderInputs = useMemo(() => {
        return listTranslated?.map((item, index) => (
            <div
                key={index}
                className='ttw-col-span-3 ttw-gap-2 ttw-grid ttw-grid-cols-[47.5%_47.5%_5%] ttw-w-full ttw-bg-white'>
                <input
                    className='ttw-border ttw-border-black ttw-rounded ttw-p-2 ttw-indent-2'
                    type='text' value={listTranslate[index]} readOnly/>
                <input
                    className='ttw-border ttw-border-black ttw-rounded ttw-p-2 ttw-indent-2'
                    type='text' placeholder={item}
                    ref={el => translatedRef.current[index] = el}
                    value={item}
                    onChange={e => handleChange(index, e)}
                />
                <button
                    onClick={(e) => {
                        e.preventDefault();
                        const newTranslated = [...listTranslated];
                        newTranslated.splice(index, 1);
                        setListTranslated(newTranslated);
                        listTranslate.splice(index, 1);
                    }}
                    className='ttw-w-fit'
                >
                    <AiFillDelete/>
                </button>
            </div>
        ));
    }, [listTranslated, dataTranslate]);

    const onTranslateNewPost = () => {
        const {
            parentPostId,
            childrenPostId,
            translatePostTitle,
            translatedPostTitle,
            translateDescription,
            translatedDescription,
            originContent,
            postType,
        } = dataTranslate?.data;


        translatePostAsync({
            parentPostId: parentPostId,
            childrenPostId: childrenPostId,
            translatePostTitle: translatePostTitle,
            translatedPostTitle: translatedPostTitle,
            translateDescription: translateDescription,
            translatedDescription: translatedDescription,
            arrayMerged: listTranslate,
            translatedQuery: listTranslated,
            originContent: originContent,
            targetLang: getLanguageCodeFromCountryCode(selected),
            postType: postType,
        }).then(res => {
            if (res?.data?.status) {
                toast.success('Translate success', {
                    style: {
                        zIndex: 9999999999999999999999
                    },
                });
            } else {
                toast.error('Translate fail', {
                    style: {
                        zIndex: 9999999999999999999999
                    },
                });
            }
        }).finally(() => {
            setTimeout(() => {
                setIsOpen(false);
            }, 5000);
        });
    };

    return (
        <>
            <div className='ttw-p-4 ttw-flex ttw-flex-col ttw-gap-5'>
                <ReactFlagsSelect
                    selected={selected} onSelect={code => setSelected(code)}
                    countries={customSelectLanguage}
                />
                <button
                    disabled={isGetTranslateLoading}
                    onClick={onGetTranslatePost}
                    className='ttw-p-2 ttw-bg-blue-600 ttw-text-white ttw-rounded disabled:ttw-opacity-50'>Translate
                </button>
            </div>
            <div
                id='defaultModal'
                className={`${
                    classNames('modal', {
                        [`ttw-flex`]: isOpen,
                        [`ttw-hidden`]: !isOpen
                    })
                }`}>
                <div className='modal-content'>
                    <div className='modal-header'>
                        <h3 className='modal-title'>Language Translate</h3>
                        <button
                            className='modal-close'
                            onClick={() => {
                                setIsOpen(false);
                            }}
                        >&times;</button>
                    </div>
                    <div
                        className='modal-body ttw-max-h-[600px] ttw-overflow-y-auto ttw-grid ttw-grid-cols-[47.5%_47.5%_5%] ttw-relative ttw-gap-x-3 ttw-overflow-x-hidden ttw-gap-y-2 ttw-w-full'>
                        <div
                            className='-ttw-mx-1 -ttw-top-1 ttw-col-span-3 ttw-gap-y-2 ttw-sticky ttw-grid ttw-grid-cols-[47.5%_47.5%_5%] ttw-w-full ttw-bg-white'>
                            <h1 className='ttw-text-xl ttw-font-semibold ttw-text-center'>Origin</h1>
                            <h1 className='ttw-text-xl ttw-font-semibold ttw-text-center'>Translated</h1>
                        </div>
                        {
                            renderInputs
                        }
                    </div>
                    <div className='modal-footer'>
                        <div className='ttw-flex ttw-w-full ttw-justify-between ttw-items-center'>
                            <p id='copyright'>
                                {`Turbo Translate @ ${new Date().getFullYear()}`}
                                <a href="turbosify.com" style={{
                                    textDecoration:"none",
                                    color:"#fff",
                                    backgroundColor: "#1175c9",
                                    padding: "5px 10px",
                                    borderRadius: "3px",
                                    fontWeight: "500",
                                    margin: "0 10px"
                                }}
                                >Upgrade Premium To Auto Translate</a>
                            </p>
                            <button
                                disabled={isTranslatePostLoading}
                                className='ttw-py-2 ttw-px-5 ttw-bg-blue-600 ttw-text-white ttw-rounded disabled:ttw-opacity-50'
                                onClick={() => onTranslateNewPost()}
                            >Save translation
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </>
    );
};

export default TranslateSelector;
