import {Button} from "../polaris/button";
import {ThumbnailImage} from "../apps/thumbnailImage";
import {PreviewSEO} from "../apps/previewSEO";
import {ItemList} from "../apps/itemList";
import {useEffect, useCallback, useState } from "react";
import {baseWordpressAjaxUrl} from "../../config/env"
import browser from "../../assets/browser.svg";

export function TranslatePage({translatePageClick}) {
  /** Back to homepage **/
  const handleBackHome = () => {
    translatePageClick(null)
  }
  const [content,setContent] = useState(null)
  const handleBackPost = () => { setContent(null)}
  const [posts, setPosts] = useState(null);
  const handleSingleTranslate = (value) => { setContent(posts[value]) }
  const [pagination,setPagination] = useState(1)
  const getPosts = useCallback(() => {
    // console.warn('Fetching list post page 1 ...')
    // console.log(baseWordpressAjaxUrl + 'translatexpress_list_post')
    fetch(baseWordpressAjaxUrl + 'translatexpress_list_post', {
      method: 'GET', 
      headers: {
        'Content-Type': 'application/json',
      },})
      .then(response => {
        if (!response.ok) {
          throw new Error('Network response was not ok');
        }
        return response.json(); 
      })
      .then(data => {
        console.warn(data);
        setPosts(data.data)
      })
      .catch(error => {
        console.warn('Error or Dev mode ', error);
        setPosts([
          {
              "title": "awesome plugin",
              "link": "http://localhost/?p=9",
              "content" : "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer id nisl in felis volutpat aliquam. Nam id imperdiet dolor. Sed augue ligula, dignissim sed nisl ac, egestas consequat odio. Nam vitae accumsan libero. Nunc porta risus a congue porta. Integer neque tortor, elementum et quam in, tincidunt maximus diam. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Cras vitae felis purus. Praesent sed convallis libero, sed cursus augue. Phasellus id elit ligula. Aliquam at tellus id sem euismod varius nec mollis dolor. Sed et eleifend nunc. Sed in nibh imperdiet, lacinia felis non, malesuada justo. Aliquam id malesuada sapien, eu finibus lectus."
          },
          {
              "title": "Hello world!",
              "link": "http://localhost/?p=1",
              "content" : "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Integer id nisl in felis volutpat aliquam. Nam id imperdiet dolor. Sed augue ligula, dignissim sed nisl ac, egestas consequat odio. Nam vitae accumsan libero. Nunc porta risus a congue porta. Integer neque tortor, elementum et quam in, tincidunt maximus diam. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos. Cras vitae felis purus. Praesent sed convallis libero, sed cursus augue. Phasellus id elit ligula. Aliquam at tellus id sem euismod varius nec mollis dolor. Sed et eleifend nunc. Sed in nibh imperdiet, lacinia felis non, malesuada justo. Aliquam id malesuada sapien, eu finibus lectus."
          }
        ]);
      });
    },[]);

  useEffect( () => {
    getPosts();
  },[]);
    return (<>

    <div className="wp-mx-auto wp-max-w-[1000px] wp-pt-10 wp-grid wp-grid-cols-2 wp-gap-4">
      <div className="wp-flex wp-gap-2">
        <div className="wp-w-[150px]">
          <Button click={handleBackHome}>Back to home</Button>
        </div>
        <div className="wp-w-[150px]">
          <Button tone="white" click={handleBackPost}>Back to post</Button>
        </div>  
      </div>
      
    </div>

    { content === null ? <>
    <div style={{height:"30px"}}></div>

    <div className="wp-mx-auto wp-max-w-[1000px]">
      <ItemList items={posts} click={handleSingleTranslate}/>
    </div>  
    
    <div style={{height:"30px"}}></div> </> :
    <>
    <div className="wp-mx-auto wp-max-w-[1000px] wp-py-10 wp-grid wp-grid-cols-2 wp-gap-4">

      <div className="wp-p-0 wp-rounded-xl wp-grid wp-grid-cols-1 wp-relative">
        <PreviewSEO title={content.title} desc={content.content} link="yourpreviewsite.com"/>
      </div>

      <div className="wp-p-4 wp-bg-white wp-rounded-xl wp-grid wp-grid-cols-1">
        <div>
          <label className="">Title translation</label>
          <input type="text" placeholder="" className="wp-border wp-rounded-xl wp-h-[35px] wp-w-full wp-mb-3" />
        </div>
        <div>
          <label className="">Url translation</label>
          <input type="text" placeholder="" className="wp-border wp-rounded-xl wp-h-[35px] wp-w-full wp-mb-3" />
        </div>
        <div>
          <label className="">Post translation</label>
          <input type="text" placeholder="" className="wp-border wp-rounded-xl wp-h-[35px] wp-w-full wp-mb-3" />
        </div>
        <div>
          <label className="">Description translation</label>
          <input type="text" placeholder="" className="wp-border wp-rounded-xl wp-h-[35px] wp-w-full wp-mb-3" />
        </div>
        <div>
          <label className="">Image translation</label>
          <input type="text" placeholder="" className="wp-border wp-rounded-xl wp-h-[35px] wp-w-full wp-mb-3" />
        </div>
        <div>
          <Button>Save</Button>
        </div>
      </div>

    </div>

    <div className="wp-mx-auto wp-max-w-[1000px] wp-py-10 wp-grid wp-grid-cols-2 wp-gap-4">

      <div className="wp-p-0 wp-rounded-xl wp-grid wp-grid-cols-1 wp-relative">
        <ThumbnailImage image={browser} w="100%" h="500px" borderRadius="0" border="none" bgSize="contains"/>
        <div className="wp-absolute wp-top-40 wp-px-16 wp-w-full ">
          <h1 className="">{content.title}</h1>
          <div>{content.link}</div>
          <div>{content.content.slice(0,30)} ...</div>

        </div>
      </div>

      <div className="wp-p-4 wp-bg-white wp-rounded-xl wp-grid wp-grid-cols-1">
        <div>
          <label className="wp-font-bold wp-flex wp-gap-2">
            <svg style={{width:"20px"}} xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M11.75 4a.75.75 0 0 0 0 1.5h4.5a.75.75 0 0 0 0-1.5h-4.5Z"/><path d="M11 8.25a.75.75 0 0 1 .75-.75h4.5a.75.75 0 0 1 0 1.5h-4.5a.75.75 0 0 1-.75-.75Z"/><path d="M3.75 11a.75.75 0 0 0 0 1.5h12.5a.75.75 0 0 0 0-1.5h-12.5Z"/><path d="M3.75 14.5a.75.75 0 0 0 0 1.5h8.5a.75.75 0 0 0 0-1.5h-8.5Z"/><path d="M3 8.75a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1v-1a1 1 0 0 0-1-1h-.5v-1a.25.25 0 0 1 .25-.25.75.75 0 0 0 0-1.5 1.75 1.75 0 0 0-1.75 1.75v3Z"/><path d="M8.5 6.75v-1a.25.25 0 0 1 .25-.25.75.75 0 0 0 0-1.5 1.75 1.75 0 0 0-1.75 1.75v3a1 1 0 0 0 1 1h1a1 1 0 0 0 1-1v-1a1 1 0 0 0-1-1h-.5Z"/></svg>
            <span>Content translation</span>
          </label>
          <div style={{height:"10px"}}></div>
          <textarea type="text" placeholder="" className="wp-h-[200px] wp-border wp-rounded-xl wp-px-4 wp-py-2 wp-w-full wp-mb-3" value={content.content}/>
          <div className="wp-grid wp-grid-cols-2 wp-gap-2">
            <Button tone="white">
              <svg style={{width:"20px"}} className="wp-absolute" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path fillRule="evenodd" d="M6.955 3.994a.75.75 0 0 0-1.41 0l-2 5.5a.75.75 0 1 0 1.41.512l.187-.514a.756.756 0 0 0 .108.008h2.111l.184.506a.75.75 0 1 0 1.41-.512l-2-5.5Zm-.705 2.45.566 1.556h-1.132l.566-1.555Z"/><path d="M14.55 7.75v-1a.25.25 0 0 0-.25-.25h-1.49l.22.22a.75.75 0 1 1-1.06 1.06l-1.5-1.5a.75.75 0 0 1 0-1.06l1.5-1.5a.75.75 0 0 1 1.06 1.06l-.22.22h1.49c.966 0 1.75.783 1.75 1.75v1a.75.75 0 1 1-1.5 0Z"/><path d="M5.5 12.25v1c0 .138.112.25.25.25h1.49l-.22-.22a.75.75 0 1 1 1.06-1.06l1.5 1.5a.75.75 0 0 1 0 1.06l-1.5 1.5a.75.75 0 0 1-1.06-1.06l.22-.22h-1.49a1.75 1.75 0 0 1-1.75-1.75v-1a.75.75 0 1 1 1.5 0Z"/><path fillRule="evenodd" d="M11.002 11.5h-.252a.75.75 0 0 1 0-1.5h1.75v-.25a.75.75 0 0 1 1.5 0v.25h1.75a.75.75 0 0 1 0 1.5h-.312a5.877 5.877 0 0 1-.4 1.945 5.13 5.13 0 0 1-.69 1.227c.293.161.634.3 1.03.402a.75.75 0 0 1-.376 1.452 5.676 5.676 0 0 1-1.782-.788 5.677 5.677 0 0 1-1.782.788.75.75 0 1 1-.376-1.452c.396-.103.737-.24 1.03-.402a5.115 5.115 0 0 1-.69-1.227 5.88 5.88 0 0 1-.4-1.945Zm2.935 0h-1.434a4.381 4.381 0 0 0 .295 1.394c.101.257.237.524.422.782.185-.258.32-.525.422-.782a4.386 4.386 0 0 0 .295-1.394Z"/></svg>
              <span>Auto translate</span>
            </Button>
            <Button>
            <svg style={{width:"20px"}} fill="white" className="wp-absolute" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><path d="M5.702 4.253a.625.625 0 0 1 1.096 0l.196.358c.207.378.517.688.895.895l.358.196a.625.625 0 0 1 0 1.097l-.358.196a2.25 2.25 0 0 0-.895.894l-.196.359a.625.625 0 0 1-1.096 0l-.196-.359a2.25 2.25 0 0 0-.895-.894l-.358-.196a.625.625 0 0 1 0-1.097l.358-.196a2.25 2.25 0 0 0 .895-.895l.196-.358Z"/><path fillRule="evenodd" d="M12.948 7.89c-.18-1.167-1.852-1.19-2.064-.029l-.03.164a3.756 3.756 0 0 1-3.088 3.031c-1.15.189-1.173 1.833-.03 2.054l.105.02a3.824 3.824 0 0 1 3.029 3.029l.032.165c.233 1.208 1.963 1.208 2.196 0l.025-.129a3.836 3.836 0 0 1 3.077-3.045c1.184-.216 1.12-1.928-.071-2.107a3.789 3.789 0 0 1-3.18-3.154Zm-.944 6.887a5.34 5.34 0 0 1 2.542-2.647 5.305 5.305 0 0 1-2.628-2.548 5.262 5.262 0 0 1-2.488 2.508 5.329 5.329 0 0 1 2.574 2.687Z"/></svg>
            <span>Grammar corrector (GPT)</span>
            </Button>
          </div>
        </div>
        
      </div>

    </div>
    </> }
    
    </>);
  }
  