import {BreadCrumb} from "../apps/breadCrumb";
import {Button} from "../polaris/button";
import {PreviewSEO} from "../apps/previewSEO";
import {ItemList} from "../apps/itemList";
import {useEffect, useCallback, useState, useRef } from "react";
import {baseWordpressAjaxUrl} from "../../config/env"
import { Toast } from "../polaris/toast.jsx";
import {QuickActionTranslate} from  "./quickAction.jsx";
import {Switcher} from "../i18n/switcher.jsx";

export function TranslatePage({setPageClick,lang}) {
  /** Back to homepage **/
  const handleBreadCrumbCallbackHome = () => {
    setPageClick(null)
    setIsoriginal(false)
  }
  const handleBreadCrumbCallbackList = () => {
    setContent(null)
    setIsoriginal(false)
  }
  /** data to save **/
  const [isoriginal,setIsoriginal] = useState(false);
  let language = useRef('en');
  const parent = useRef(null);
  const children = useRef(null);
  const original = useRef(null);
  let savepostid = useRef(null)
  /** http post to save **/
  const saveTranslation = useCallback(() => {
    setLoading(true)
    fetch(baseWordpressAjaxUrl + 'translatexpress_save_post', {
      method: 'POST', 
      headers: {
        'Content-Type': 'application/json',
        },
        body: JSON.stringify({
          language: language.current,
          children: children.current,
          parent: parent.current,
          original: original.current,
          postId : savepostid.current,
        })  
      })
      .then(response => {
        if (!response.ok) {
          throw new Error('Network response was not ok');
        }
        return response.json(); 
      })
      .then(data => {
        console.warn(data);
      })
      .catch(error => {
        console.warn('Error or Dev mode ', error);
      });
      setTimeout(function(){
        setLoading(false)
      },1200);
    },[]);
  /** handle translate **/
  const [content,setContent] = useState(null)
  const [loading,setLoading] = useState(false)
  const [posts, setPosts] = useState(null);
  const handleSingleTranslate = (value) => { 
    savepostid.current = posts[value].id;
    setContent(posts[value]) 
  }
  const getPosts = useCallback(() => {
    setLoading(true)
    fetch(baseWordpressAjaxUrl + 'translatexpress_list_post', {
      method: 'GET', 
      headers: {
        'Content-Type': 'application/json',
      },})
      .then(response => {
        if (!response.ok) {
          throw new Error('Network response was not ok');
        }
        return response.json(); 
      })
      .then(data => {
        console.warn(data);
        setPosts(data.data);

      })
      .catch(error => {
        console.warn('Error or Dev mode ', error);
        
        setPosts([
          {
              "title": "test review",
              "link": "http://localhost/?page_id=18",
              "id": 18,
              "translate": {
                  "translate": false,
                  "language": false,
                  "parent": false,
                  "children": false,
                  "original": false
              },
              "review": true
          },
          {
              "title": "test",
              "link": "http://localhost/?page_id=15",
              "id": 15,
              "translate": {
                  "translate": false,
                  "language": false,
                  "parent": false,
                  "children": false,
                  "original": false
              },
              "review": false
          },
          {
              "title": "booking",
              "link": "http://localhost/?page_id=11",
              "id": 11,
              "translate": {
                  "translate": false,
                  "language": false,
                  "parent": false,
                  "children": false,
                  "original": false
              },
              "review": true
          },
          {
              "title": "Privacy Policy",
              "link": "http://localhost/?page_id=3",
              "id": 3,
              "translate": {
                  "translate": false,
                  "language": false,
                  "parent": false,
                  "children": false,
                  "original": false
              },
              "review": false
          },
          {
              "title": "catalogo",
              "link": "http://localhost/?page_id=2",
              "id": 2,
              "translate": {
                  "translate": [
                      "1"
                  ],
                  "language": [
                      "en"
                  ],
                  "parent": false,
                  "children": [
                      "1,2,3"
                  ],
                  "original": [
                      "1"
                  ]
              },
              "review": true
          },
          {
              "title": "Hello world!",
              "link": "http://localhost/?p=1",
              "id": 1,
              "translate": {
                  "translate": false,
                  "language": false,
                  "parent": false,
                  "children": false,
                  "original": false
              },
              "review": true
          }
      ]);
      });
      setLoading(false)
    },[]);

  useEffect( () => {
    getPosts();
  },[]);

    return (<>

    <div className="wp-mx-auto wp-max-w-[1000px] wp-pt-10 wp-grid wp-grid-cols-2 wp-gap-4">
        <BreadCrumb showSingle={content === null ? false : true} clickHome={handleBreadCrumbCallbackHome} clickList={handleBreadCrumbCallbackList}/>
    </div>

    <QuickActionTranslate lang={lang} quickActionTranslate={(event) => console.warn(event)}/>

    <Toast status={loading}/>

    { content === null ? <>
    <div style={{height:"30px"}}></div>

    <div className="wp-mx-auto wp-max-w-[1000px]">
      <ItemList items={posts} click={handleSingleTranslate} buttonName="Translate" template="translate"/>
    </div>  
    
    <div style={{height:"30px"}}></div> </> :
    <>
    <div className="wp-mx-auto wp-max-w-[1000px] wp-py-10 wp-grid wp-grid-cols-1">

      <div className="wp-p-0 wp-rounded-xl wp-grid wp-grid-cols-1 wp-relative wp-border wp-border-2 wp-py-10 wp-px-4">
        <PreviewSEO title={content.title} desc={content.content} link={content.link}/>
      </div>

      <div style={{height:"60px"}}></div>

      <div className="wp-p-4 wp-bg-white wp-rounded-xl wp-grid wp-grid-cols-1">

      <div className="wp-grid wp-grid-cols-2 wp-gap-4">
          <label className="wp-text-lg wp-font-bold wp-mb-3 wp-text-black wp-border-b wp-pb-2 wp-text-lg wp-self-center">Original post :</label>
          <div class="wp-inline-flex wp-items-center">
          <label class="container_checkbox">
            <input type="checkbox" onChange={
              () => {
                original.current = !original.current;
                setIsoriginal(!isoriginal)
              }}/>
            <svg viewBox="0 0 64 64" height="2em" width="2em">
              <path d="M 0 16 V 56 A 8 8 90 0 0 8 64 H 56 A 8 8 90 0 0 64 56 V 8 A 8 8 90 0 0 56 0 H 8 A 8 8 90 0 0 0 8 V 16 L 32 48 L 64 16 V 8 A 8 8 90 0 0 56 0 H 8 A 8 8 90 0 0 0 8 V 56 A 8 8 90 0 0 8 64 H 56 A 8 8 90 0 0 64 56 V 16" pathLength="575.0541381835938" class="path"></path>
            </svg>
          </label>
          </div> 
        </div>   

        <div style={{height:"30px"}}></div>


        <div className="wp-grid wp-grid-cols-2 wp-gap-4" style={{
          display: isoriginal === false ? "" : "none"
        }}>
          <label className="wp-font-bold wp-text-black wp-border-b wp-pb-2 wp-text-left">Choose language</label>
          <Switcher translate={(event) => {
            language.current = event;
            }} width="100%"/>
        </div>     
        <div style={{height:"10px"}}></div>

        <div className="wp-grid wp-grid-cols-2 wp-gap-4" style={{
          display: isoriginal === true ? "" : "none"
        }}>
          <label className="wp-font-bold wp-text-black wp-border-b wp-pb-2 wp-text-left">Setup child post ( translated post )</label>
          <input type="text" disabled={isoriginal === false ? "checked" : null } onChange={(event) => children.current = event.target.value} placeholder="1,2,5" class="wp-px-2 wp-border wp-rounded-xl wp-h-[35px] wp-w-full"/>
        </div>    
        <div style={{height:"10px"}}></div>

        <div className="wp-grid wp-grid-cols-2 wp-gap-4" style={{
          display: isoriginal === false ? "" : "none"
        }}>
          <label className="wp-font-bold wp-text-black wp-border-b wp-pb-2 wp-text-left">Setup parent post</label>
          <input type="text" disabled={ isoriginal === true ? "checked" : null } onChange={(event) => parent.current = event.target.value} placeholder="1,2,5" class="wp-px-2 wp-border wp-rounded-xl wp-h-[35px] wp-w-full"/>
        </div>    
        
        <div style={{height:"30px"}}></div>

        <div className="wp-w-[200px] wp-mx-auto">
            <Button click={saveTranslation}>Save</Button>
        </div>


      </div>

    </div>

    </> }
    
    </>);
  }
  