import axios from '../config/axios';
import { useMutation, useQuery } from 'react-query';
import { baseWordpressAjaxUrl } from '../config/env';

/**
 *
 * @returns {Promise<axios.AxiosResponse<any>>}
 */

const getLanguage = async () => {
	const payload = new FormData();
	payload.append('action', 'turbotranslate_get_country_code_selected');
	return axios.post(`${ baseWordpressAjaxUrl }`, payload);
};

export const useLanguage = (options = {}) => {
	const queryKey = ['GET_LANGUAGE'];

	return useQuery(queryKey, getLanguage);
};

/**
 *
 * @param url {string}
 * @returns {Promise<axios.AxiosResponse<any>>}
 */
const getPostByUrl = async (url) => {
	const payload = new FormData();
	payload.append('action', 'turbotranslate_get_post_id_from_url');
	payload.append('url', url);
	return axios.post(`${ baseWordpressAjaxUrl }`, payload);
};

export const usePostByUrl = (url, options = {}) => {
	const queryKey = ['GET_POST_BY_URL', url];

	return useQuery(queryKey, () => getPostByUrl(url), {
		...options,
		enabled: true,
	});
};

/**
 *
 * @param postId {number}
 * @param language {?string[]}
 * @returns {Promise<void>}
 */

const getPostByLanguage = async ({ postId, language = [] }) => {
	const payload = new FormData();
	payload.append('action', 'turbotranslate_get_posts_group_by_language');
	payload.append('post_id', String(postId));
	language.length && language.forEach((lang) => payload.append('arrCountryCode[]', lang));
	return axios.post(`${ baseWordpressAjaxUrl }`, payload);
};


export const usePostByLanguage = () => {
	const queryKey = ['GET_POST_BY_LANGUAGE'];
	return useMutation(queryKey, getPostByLanguage);
};

/**
 *
 * @param postParentId
 * @param targetLanguage
 * @returns {Promise<axios.AxiosResponse<any>>}
 */
const getPostChildren = async ({ postParentId, targetLanguage }) => {
	const payload = new FormData();
	payload.append('action', 'turbotranslate_get_post_children_by_target_lang');
	payload.append('target_lang', targetLanguage);
	payload.append('postParentID', postParentId);
	return axios.post(`${ baseWordpressAjaxUrl }`, payload);
};

export const usePostChildren = () => {
	const queryKey = ['GET_POST_CHILDREN'];
	return useMutation(queryKey, getPostChildren);
};


/**
 *
 * @returns {Promise<axios.AxiosResponse<any>>}
 */
const getStyle = async () => {
	const payload = new FormData();
	payload.append('action', 'turbotranslate_get_style_switcher');
	return axios.post(`${ baseWordpressAjaxUrl }`, payload);
};

export const useStyle = (options = {}) => {
	const queryKey = ['GET_STYLE'];

	return useQuery(queryKey, getStyle, {
		...options,
	});
};


/**
 * @param postId
 * @param targetLang
 * @param shop
 * @returns {Promise<axios.AxiosResponse<any>>}
 */
const getTranslatePost = async ({ postId, targetLang, shop }) => {
	const payload = new FormData();
	payload.append('action', 'translate_gg_api');
	payload.append('postId', postId);
	payload.append('target_lang', targetLang);
	payload.append('shop', shop);
	return axios.post(`${ baseWordpressAjaxUrl }`, payload);
};


export const useGetTranslatePost = () => {
	const queryKey = ['TRANSLATE_POST'];
	return useMutation(queryKey, getTranslatePost);
};


/**
 *
 * @param parent_post_id
 * @param children_post_id
 * @param translate_post_title
 * @param translated_post_title
 * @param translate_description
 * @param translated_description
 * @param array_merged
 * @param translated_query
 * @param origin_content
 * @param target_lang
 * @param post_type
 * @returns {Promise<axios.AxiosResponse<any>>}
 */
const translatePost = async ({
	                             parentPostId,
	                             childrenPostId,
	                             translatePostTitle,
	                             translatedPostTitle,
	                             translateDescription,
	                             translatedDescription,
	                             arrayMerged,
	                             translatedQuery,
	                             originContent,
	                             targetLang,
	                             postType
                             }) => {
	const payload = new FormData();
	payload.append('action', 'turbotranslate_edit_translated_post');
	payload.append('parent_post_id', parentPostId);
	payload.append('children_post_id', childrenPostId);
	payload.append('translate_post_title', translatePostTitle);
	payload.append('translated_post_title', translatedPostTitle);
	payload.append('translate_description', translateDescription);
	payload.append('translated_description', translatedDescription);
	for (let i = 0; i < arrayMerged.length; i++) {
		payload.append('array_merged[]', arrayMerged[i]);
	}
	for (let i = 0; i < translatedQuery.length; i++) {
		payload.append('translated_query[]', translatedQuery[i]);
	}
	payload.append('origin_content', originContent);
	payload.append('target_lang', targetLang);
	payload.append('post_type', postType);

	return axios.post(`${ baseWordpressAjaxUrl }`, payload);
};

export const useTranslatePost = () => {
	const queryKey = ['TRANSLATE_POST_EDIT'];
	return useMutation(queryKey, translatePost);
};
